@@ -151,8 +151,9 @@ class SHCAPI:
                         "data": device.data,
                         "sIT600TH": {
                             "SetHoldType":
-                                7 if mode == HVAC_MODE_OFF else device.previous_mode
-                                if not device.previous_mode == HVAC_MODE_OFF else 7
+                                7 if mode == HVAC_MODE_OFF
+                                else 2 if device.previous_mode == PRESET_PERMANENT_HOLD
+                                else 0
                         }
                     }
                 ]
