@@ -93,14 +93,14 @@ class SALUSThermostat(SALUSDevice):
     def process_long_polling_poll_result(self, raw_result):
         super().process_long_polling_poll_result(raw_result)
 
-    async def set_temperature(self, celsius: float):
-        await self._api.set_temperature(self, celsius)
+    def set_temperature(self, celsius: float):
+        self._api.set_temperature(self, celsius)
 
-    async def set_climate_device_mode(self, mode: str):
-        await self._api.set_climate_device_mode(self, mode)
+    def set_climate_device_mode(self, mode: str):
+        self._api.set_climate_device_mode(self, mode)
 
-    async def set_climate_device_preset(self, preset: str):
-        await self._api.set_climate_device_preset(self, preset)
+    def set_climate_device_preset(self, preset: str):
+        self._api.set_climate_device_preset(self, preset)
         self._previous_mode = preset
 
     @property
